@@ -26,6 +26,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
+#include <unique/unique.h>
+
 #include "brasero-session-cfg.h"
 
 G_BEGIN_DECLS
@@ -53,7 +55,7 @@ struct _BraseroApp
 GType brasero_app_get_type (void) G_GNUC_CONST;
 
 BraseroApp *
-brasero_app_new (void);
+brasero_app_new (UniqueApp *gapp);
 
 BraseroApp *
 brasero_app_get_default (void);
@@ -157,9 +159,6 @@ brasero_app_get_statusbar1 (BraseroApp *app);
 GtkWidget *
 brasero_app_get_statusbar2 (BraseroApp *app);
 
-GtkUIManager *
-brasero_app_get_ui_manager (BraseroApp *app);
-
 GtkWidget *
 brasero_app_get_project_manager (BraseroApp *app);
 
@@ -175,8 +174,6 @@ brasero_app_get_saved_contents (BraseroApp *app);
 gboolean
 brasero_app_save_contents (BraseroApp *app,
 			   gboolean cancellable);
-void
-brasero_app_save_window_state (BraseroApp *app);
 
 G_END_DECLS
 
